==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/AdSpace.pm <==
package WebGUI::i18n::Spanish::AdSpace;
use utf8;
our $I18N = {
  'ad id' => {
    'lastUpdated' => '1252510921',
    'message' => 'ID de la Publicidad'
  },
  'ad space id' => {
    'lastUpdated' => '1223923928',
    'message' => 'ID del Espacio Publicitario'
  },
  'ad text' => {
    'lastUpdated' => '1223923939',
    'message' => 'Texto de la Publicidad'
  },
  'ad text help' => {
    'lastUpdated' => '1223923974',
    'message' => 'Escriba hasta un m&aacute;ximo de 255 caracteres con el texto que le gustar&iacute;a ver aparecer en esta Publicidad. Tenga en cuenta que dependiendo del tama&ntilde;o del anuncio, es posible que no pueda leerse todo el texto. Se recomienda mantenerlo en 60 caracteres o menos.'
  },
  'add ad space' => {
    'lastUpdated' => '1223923987',
    'message' => 'A&ntilde;adir Espacio Publicitario'
  },
  'add ad space body' => {
    'lastUpdated' => '1223924013',
    'message' => 'Esta pantalla presenta una lista con todos los Espacios Publicitarios disponibles en WebGUI. Los &iacute;conos al lado de cada Espacio Publicitario le permiten editarlo o eliminarlo. Adicionalmente, encontrar&aacute; un enlace que le permite a&ntilde;adir nuevos Espacios Publicitario.'
  },
  'add an ad' => {
    'lastUpdated' => '1223924041',
    'message' => 'Agregar una Publicidad.'
  },
  'background color' => {
    'lastUpdated' => '1223923452',
    'message' => 'Color de fondo'
  },
  'background color help' => {
    'lastUpdated' => '1223924063',
    'message' => 'Color de fondo para la Publicidad, expresado en RGB hexadecimal.'
  },
  'border color' => {
    'lastUpdated' => '1223923505',
    'message' => 'Color del borde'
  },
  'border color help' => {
    'lastUpdated' => '1223924086',
    'message' => 'Color del borde para la Publicidad, expresado en RGB hexadecimal.'
  },
  'clicks bought' => {
    'lastUpdated' => '1223923600',
    'message' => 'Clicks comprados'
  },
  'clicks bought help' => {
    'lastUpdated' => '1223923635',
    'message' => '&iquest;Cu&aacute;ntos clics ha comprado el anunciante? Si se adquiri&oacute; un n&uacute;mero de impresiones puede dejar &eacute;sta en cero.'
  },
  'confirm ad delete' => {
    'lastUpdated' => '1223924101',
    'message' => '&iquest;Est&aacute; seguro que desea borrar esta Publicidad?'
  },
  'confirm ad space delete' => {
    'lastUpdated' => '1223924128',
    'message' => '&iquest;Est&aacute; seguro que quieres eliminar este Espacio Publicitario y todas las Publicidades asociadas?'
  },
  'description' => {
    'lastUpdated' => '1223923706',
    'message' => 'Descripci&oacute;n'
  },
  'description help' => {
    'lastUpdated' => '1223924148',
    'message' => 'Una descripci&oacute;n de la ubicaci&oacute;n de este Espacio Publicitario en el sitio.'
  },
  'edit ad space' => {
    'lastUpdated' => '1223924161',
    'message' => 'Editar Espacio Publicitario'
  },
  'edit advertisement' => {
    'lastUpdated' => '1223924179',
    'message' => 'Editar Publicidad'
  },
  'edit this ad space' => {
    'lastUpdated' => '1223924194',
    'message' => 'Editar este Espacio Publicitario.'
  },
  'error heading' => {
    'lastUpdated' => '1223924222',
    'message' => 'Hay un error en su Espacio Publicitario:'
  },
  'error invalid characters' => {
    'lastUpdated' => '1223924268',
    'message' => 'El t&iacute;tulo solamente puede contener letras, n&uacute;meros y espacios en blanco.'
  },
  'height' => {
    'lastUpdated' => '1223925271',
    'message' => 'Altura'
  },
  'height help' => {
    'lastUpdated' => '1223924291',
    'message' => 'Altura en p&iacute;xeles para el Espacio Publicitario.'
  },
  'image' => {
    'lastUpdated' => '1223924312',
    'message' => 'Imagen'
  },
  'image help' => {
    'lastUpdated' => '1252511040',
    'message' => 'La imagen que se mostrará en cada presentación de la Publicidad.'
  },
  'impressions bought' => {
    'lastUpdated' => '1252512536',
    'message' => 'Impresiones Compradas'
  },
  'impressions bought help' => {
    'lastUpdated' => '1252512547',
    'message' => '¿Cuántas impresiones ha comprado el anunciante? Si se adquirió un número de clicks, puede dejar éste en cero.'
  },
  'is active' => {
    'lastUpdated' => '1223924458',
    'message' => 'Activo?'
  },
  'is active help' => {
    'lastUpdated' => '1223924479',
    'message' => '&iquest;Incluir esta Publicidad en la rotaci&oacute;n?'
  },
  'macro code prompt' => {
    'lastUpdated' => '1223924502',
    'message' => 'Utilice este c&oacute;digo para colocar este Espacio Publicitario:'
  },
  'manage ad spaces' => {
    'lastUpdated' => '1223924514',
    'message' => 'Administrar Espacios Publicitarios.'
  },
  'minimum clicks' => {
    'lastUpdated' => '1253708598',
    'message' => 'Cantidad Mínima de Clicks a comprar'
  },
  'minimum clicks help' => {
    'lastUpdated' => '1253708606',
    'message' => 'Especifique el número mínimo de clicks que el usuario debe adquirir cuando compra una Publicidad en este Espacio Publicitario.'
  },
  'minimum impressions' => {
    'lastUpdated' => '1253708589',
    'message' => 'Cantidad Mínima de Impresiones a Comprar'
  },
  'minimum impressions help' => {
    'lastUpdated' => '1253708616',
    'message' => 'Especifique el número mínimo de impresiones que el usuario debe adquirir cuando compra una Publicidad en este Espacio Publicitario.'
  },
  'name' => {
    'lastUpdated' => '1223924524',
    'message' => 'Nombre'
  },
  'name help' => {
    'lastUpdated' => '1223924588',
    'message' => 'El nombre se utiliza en combinaci&oacute;n con el macro AdSpace para permitir la publicaci&oacute;n de anuncios en el sitio. Debe contener solamente caracteres alfanum&eacute;ricos sin espacios.'
  },
  'priority' => {
    'lastUpdated' => '1223924599',
    'message' => 'Prioridad'
  },
  'priority help' => {
    'lastUpdated' => '1223924912',
    'message' => 'Mecanismo de escalamiento para determinar con que frecuencia debe mostrarse una Publicidad. Mientras m&aacute;s bajo sea el n&uacute;mero, se mostrar&aacute; con m&aacute;s frecuencia. El mecanismo no afecta a sitios con bajo tr&aacute;fico. Si la Publicidad&nbsp;A tiene prioridad 0, la Publicidad&nbsp;B tiene prioridad 10, y el sitio tiene un promedio de una presentaci&oacute;n por segundo entonces la Publicidad&nbsp;A se mostrar&aacute; alrededor de 100 veces m&aacute;s que la Publicidad&nbsp;B. Tenga en cuenta que esta propiedad es un mecanismo simple de escalamiento, pero no se trata de un promedio exacto. Mientras m&aacute;s tr&aacute;fico sostenga el sitio, el efecto de la prioridad ser&aacute; m&aacute;s notorio.'
  },
  'rich' => {
    'lastUpdated' => '1223924942',
    'message' => 'Medios (Flash, JavaScript, etc.)'
  },
  'rich help' => {
    'lastUpdated' => '1223924986',
    'message' => 'Coloque el c&oacute;digo que se utilizar&aacute; para generar la Publicidad a presentar.'
  },
  'text' => {
    'lastUpdated' => '1223924995',
    'message' => 'Texto'
  },
  'text color' => {
    'lastUpdated' => '1223925005',
    'message' => 'Color del texto'
  },
  'text color help' => {
    'lastUpdated' => '1223925049',
    'message' => 'Color del texto, expresado en RGB hexadecimal.'
  },
  'title' => {
    'lastUpdated' => '1223925060',
    'message' => 'T&iacute;tulo'
  },
  'title help' => {
    'lastUpdated' => '1223925094',
    'message' => 'Etiqueta legible.'
  },
  'topicName' => {
    'lastUpdated' => '1223925103',
    'message' => 'Publicidad'
  },
  'type' => {
    'lastUpdated' => '1223925113',
    'message' => 'Tipo'
  },
  'type help' => {
    'lastUpdated' => '1223925153',
    'message' => '&iquest;Qu&eacute; tipo de Publicidad estamos incluyendo?'
  },
  'url' => {
    'lastUpdated' => '1223925165',
    'message' => 'URL'
  },
  'url help' => {
    'lastUpdated' => '1223925201',
    'message' => 'URL a la que este anuncio estar&aacute; vinculado. Tenga en cuenta que no ser&aacute; utilizada para los anuncios Rich Media.'
  },
  'used' => {
    'lastUpdated' => '1223925247',
    'message' => 'Usado'
  },
  'width' => {
    'lastUpdated' => '1223925259',
    'message' => 'Anchura'
  },
  'width help' => {
    'lastUpdated' => '1223925306',
    'message' => 'Anchura en p&iacute;xeles para el Espacio Publicitario.'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/AdSpace.pm <==
package WebGUI::i18n::Spanish::AdSpace;
use utf8;
our $I18N = {
  'ad id' => {
    'lastUpdated' => '1252510921',
    'message' => 'ID de la Publicidad'
  },
  'ad space id' => {
    'lastUpdated' => '1223923928',
    'message' => 'ID del Espacio Publicitario'
  },
  'ad text' => {
    'lastUpdated' => '1223923939',
    'message' => 'Texto de la Publicidad'
  },
  'ad text help' => {
    'lastUpdated' => '1291130203',
    'message' => 'Escriba no más de 255 caracteres con el texto que ha de aparecer en esta Publicidad. Tenga en cuenta que dependiendo del tamaño del anuncio, es posible que no pueda leerse todo el texto. Se recomienda mantenerlo en 60 caracteres o menos.'
  },
  'add ad space' => {
    'lastUpdated' => '1291130215',
    'message' => 'Añadir Espacio Publicitario'
  },
  'add ad space body' => {
    'lastUpdated' => '1223924013',
    'message' => 'Esta pantalla presenta una lista con todos los Espacios Publicitarios disponibles en WebGUI. Los &iacute;conos al lado de cada Espacio Publicitario le permiten editarlo o eliminarlo. Adicionalmente, encontrar&aacute; un enlace que le permite a&ntilde;adir nuevos Espacios Publicitario.'
  },
  'add an ad' => {
    'lastUpdated' => '1291130228',
    'message' => 'Añadir Publicidad.'
  },
  'background color' => {
    'lastUpdated' => '1223923452',
    'message' => 'Color de fondo'
  },
  'background color help' => {
    'lastUpdated' => '1223924063',
    'message' => 'Color de fondo para la Publicidad, expresado en RGB hexadecimal.'
  },
  'border color' => {
    'lastUpdated' => '1223923505',
    'message' => 'Color del borde'
  },
  'border color help' => {
    'lastUpdated' => '1223924086',
    'message' => 'Color del borde para la Publicidad, expresado en RGB hexadecimal.'
  },
  'clicks bought' => {
    'lastUpdated' => '1223923600',
    'message' => 'Clicks comprados'
  },
  'clicks bought help' => {
    'lastUpdated' => '1291130280',
    'message' => '¿Cuántos clicks ha comprado el anunciante? Puede dejarse en cero, si el anunciante adquirió un número de impresiones en lugar de un número de clicks.'
  },
  'confirm ad delete' => {
    'lastUpdated' => '1291130321',
    'message' => '¿Está seguro que desea borrar esta Publicidad?'
  },
  'confirm ad space delete' => {
    'lastUpdated' => '1291130340',
    'message' => '¿Está seguro que desea borrar este Espacio Publicitario y todas las Publicidades asociadas?'
  },
  'description' => {
    'lastUpdated' => '1291130347',
    'message' => 'Descripción'
  },
  'description help' => {
    'lastUpdated' => '1291130366',
    'message' => 'Una descripción para la ubicación de este Espacio Publicitario en el sitio.'
  },
  'edit ad space' => {
    'lastUpdated' => '1223924161',
    'message' => 'Editar Espacio Publicitario'
  },
  'edit advertisement' => {
    'lastUpdated' => '1223924179',
    'message' => 'Editar Publicidad'
  },
  'edit this ad space' => {
    'lastUpdated' => '1223924194',
    'message' => 'Editar este Espacio Publicitario.'
  },
  'error heading' => {
    'lastUpdated' => '1223924222',
    'message' => 'Hay un error en su Espacio Publicitario:'
  },
  'error invalid characters' => {
    'lastUpdated' => '1291130386',
    'message' => 'El título solamente puede contener letras, números y espacios en blanco.'
  },
  'height' => {
    'lastUpdated' => '1223925271',
    'message' => 'Altura'
  },
  'height help' => {
    'lastUpdated' => '1291130398',
    'message' => 'Altura en pixels para el Espacio Publicitario.'
  },
  'image' => {
    'lastUpdated' => '1223924312',
    'message' => 'Imagen'
  },
  'image help' => {
    'lastUpdated' => '1252511040',
    'message' => 'La imagen que se mostrará en cada presentación de la Publicidad.'
  },
  'impressions bought' => {
    'lastUpdated' => '1252512536',
    'message' => 'Impresiones Compradas'
  },
  'impressions bought help' => {
    'lastUpdated' => '1291130432',
    'message' => '¿Cuántas impresiones ha comprado el anunciante? Puede dejarse en cero si el anunciante adquirió un número de clicks en lugar de impresiones.'
  },
  'is active' => {
    'lastUpdated' => '1291130439',
    'message' => '¿Activo?'
  },
  'is active help' => {
    'lastUpdated' => '1291130454',
    'message' => '¿Incluir esta Publicidad en la rotación?'
  },
  'macro code prompt' => {
    'lastUpdated' => '1291130495',
    'message' => 'Utilice este macro en aquellas plantillas donde quiera incluir este Espacio Publicitario:'
  },
  'manage ad spaces' => {
    'lastUpdated' => '1223924514',
    'message' => 'Administrar Espacios Publicitarios.'
  },
  'minimum clicks' => {
    'lastUpdated' => '1253708598',
    'message' => 'Cantidad Mínima de Clicks a comprar'
  },
  'minimum clicks help' => {
    'lastUpdated' => '1253708606',
    'message' => 'Especifique el número mínimo de clicks que el usuario debe adquirir cuando compra una Publicidad en este Espacio Publicitario.'
  },
  'minimum impressions' => {
    'lastUpdated' => '1253708589',
    'message' => 'Cantidad Mínima de Impresiones a Comprar'
  },
  'minimum impressions help' => {
    'lastUpdated' => '1253708616',
    'message' => 'Especifique el número mínimo de impresiones que el usuario debe adquirir cuando compra una Publicidad en este Espacio Publicitario.'
  },
  'name' => {
    'lastUpdated' => '1223924524',
    'message' => 'Nombre'
  },
  'name help' => {
    'lastUpdated' => '1223924588',
    'message' => 'El nombre se utiliza en combinaci&oacute;n con el macro AdSpace para permitir la publicaci&oacute;n de anuncios en el sitio. Debe contener solamente caracteres alfanum&eacute;ricos sin espacios.'
  },
  'priority' => {
    'lastUpdated' => '1223924599',
    'message' => 'Prioridad'
  },
  'priority help' => {
    'lastUpdated' => '1223924912',
    'message' => 'Mecanismo de escalamiento para determinar con que frecuencia debe mostrarse una Publicidad. Mientras m&aacute;s bajo sea el n&uacute;mero, se mostrar&aacute; con m&aacute;s frecuencia. El mecanismo no afecta a sitios con bajo tr&aacute;fico. Si la Publicidad&nbsp;A tiene prioridad 0, la Publicidad&nbsp;B tiene prioridad 10, y el sitio tiene un promedio de una presentaci&oacute;n por segundo entonces la Publicidad&nbsp;A se mostrar&aacute; alrededor de 100 veces m&aacute;s que la Publicidad&nbsp;B. Tenga en cuenta que esta propiedad es un mecanismo simple de escalamiento, pero no se trata de un promedio exacto. Mientras m&aacute;s tr&aacute;fico sostenga el sitio, el efecto de la prioridad ser&aacute; m&aacute;s notorio.'
  },
  'rich' => {
    'lastUpdated' => '1223924942',
    'message' => 'Medios (Flash, JavaScript, etc.)'
  },
  'rich help' => {
    'lastUpdated' => '1223924986',
    'message' => 'Coloque el c&oacute;digo que se utilizar&aacute; para generar la Publicidad a presentar.'
  },
  'text' => {
    'lastUpdated' => '1223924995',
    'message' => 'Texto'
  },
  'text color' => {
    'lastUpdated' => '1223925005',
    'message' => 'Color del texto'
  },
  'text color help' => {
    'lastUpdated' => '1223925049',
    'message' => 'Color del texto, expresado en RGB hexadecimal.'
  },
  'title' => {
    'lastUpdated' => '1291130510',
    'message' => 'Título'
  },
  'title help' => {
    'lastUpdated' => '1223925094',
    'message' => 'Etiqueta legible.'
  },
  'topicName' => {
    'lastUpdated' => '1223925103',
    'message' => 'Publicidad'
  },
  'type' => {
    'lastUpdated' => '1223925113',
    'message' => 'Tipo'
  },
  'type help' => {
    'lastUpdated' => '1291130522',
    'message' => '¿Qué tipo de Publicidad estamos incluyendo?'
  },
  'url' => {
    'lastUpdated' => '1223925165',
    'message' => 'URL'
  },
  'url help' => {
    'lastUpdated' => '1223925201',
    'message' => 'URL a la que este anuncio estar&aacute; vinculado. Tenga en cuenta que no ser&aacute; utilizada para los anuncios Rich Media.'
  },
  'used' => {
    'lastUpdated' => '1223925247',
    'message' => 'Usado'
  },
  'width' => {
    'lastUpdated' => '1223925259',
    'message' => 'Anchura'
  },
  'width help' => {
    'lastUpdated' => '1291130541',
    'message' => 'Anchura en pixels para el Espacio Publicitario.'
  }
}
;

1;
